Documentation
¶
Index ¶
Constants ¶
const ( OptionFzfKey = "fzf-key" FzfKeyCTRL_T = "ctrl-t" FzfKeyCTRL_A = "ctrl-a" FzfKeyCTRL_P = "ctrl-p" FzfKeyCTRL_N = "ctrl-n" FzfKeyCTRL_D = "ctrl-d" FzfKeyCTRL_V = "ctrl-v" )
Variables ¶
Functions ¶
func GetCtrlKeysOptions ¶
func GetCtrlKeysOptions() []string
Types ¶
type Frontend ¶
type Frontend interface {
// StartFromReader starts the frontend and read entries from the reader
StartFromReader(io.Reader, *config.Config) error
// GetSelection waits for the input and return the selection
GetSelection() (string, map[string]string, error)
// AllowLocalExecution returns true if the frontend allows some entry to be
// launched without a remote.
AllowLocalExecution() bool
}
type FzfFrontend ¶
type FzfFrontend struct {
// contains filtered or unexported fields
}
func NewFzfFrontend ¶
func NewFzfFrontend() *FzfFrontend
func (*FzfFrontend) AllowLocalExecution ¶
func (f *FzfFrontend) AllowLocalExecution() bool
func (*FzfFrontend) GetSelection ¶
func (f *FzfFrontend) GetSelection() (string, map[string]string, error)
func (*FzfFrontend) StartFromReader ¶
Click to show internal directories.
Click to hide internal directories.